@@ -44,7 +44,7 @@ class OCS:
                     Key=key,
                     Body=f
                 )
-                print(resp)
+                logging.debug(resp)
         except ClientError as e:
             if e.response['ResponseMetadata']['HTTPStatusCode'] // 100 == 4:
                 logging.error('client error with invalid parameter')
@@ -83,8 +83,29 @@ class OCS:
         except Exception as e:  # other errors such as network io
             logging.error('other error such as network io:' + str(e))
 
-    def delete_object(self):
-        pass
+    def delete_object(self, key):
+        """The DELETE operation remove the object storage in OCS.
+
+        refer to https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.delete_object
+        """
+        try:
+            resp = self.s3_client.delete_object(
+                Bucket=self.bucket_name,
+                Key=key,
+            )
+            logging.debug(resp)
+
+        except ClientError as e:
+            if e.response['ResponseMetadata']['HTTPStatusCode'] // 100 == 4:
+                logging.error('client error with invalid parameter')
+            elif e.response['ResponseMetadata']['HTTPStatusCode'] // 100 == 5:
+                logging.error('ocs server internal error')
+            else:
+                logging.error('other ocs errors')
+            logging.error(e.response)
+
+        except Exception as e:  ## other errors such as network io
+            logging.error('other error such as network io:' + str(e))
 
     def list_objects(self):
         """
@@ -162,3 +183,4 @@ def get_ocs_obj(env='test', bucket='ntt'):
 
 if __name__ == '__main__':
     ocs_agent = get_ocs_obj('test', 'wayne')
+    ocs_agent.delete_object('debug/hr/a.jpg')
